package com.mcwl.web.controller.pay.AliPay;

import com.alipay.easysdk.factory.Factory;
import com.alipay.easysdk.kernel.Config;
import com.alipay.easysdk.payment.common.models.AlipayTradeCancelResponse;
import com.alipay.easysdk.payment.common.models.AlipayTradeCloseResponse;
import com.alipay.easysdk.payment.common.models.AlipayTradeQueryResponse;
import com.mcwl.common.JSONUtils;
import com.mcwl.common.core.controller.BaseController;
import com.mcwl.common.core.domain.AjaxResult;
import com.mcwl.common.core.page.TableDataInfo;
import com.mcwl.common.core.redis.RedisCache;
import com.mcwl.common.domain.IdsParam;
import com.mcwl.common.utils.SecurityUtils;
import com.mcwl.pay.domain.OrderTrade;
import com.mcwl.pay.service.AliPayService;
import com.mcwl.pay.service.OrderTradeService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import javax.validation.constraints.NotBlank;
import java.util.List;
import java.util.Map;

/**
 * @Author：ChenYan
 * @Project：McWl
 * @Package：com.mcwl.web.controller.pay
 * @Filename：OrderTradeController
 * @Description 支付模块
 * @Date：2025/1/3 14:46
 */

@RestController
@RequestMapping("/web/pay")
@Validated
@Api(tags = "订单模块")
public class OrderTradeController extends BaseController {

    @Autowired
    private Config config;

    @Autowired
    private OrderTradeService orderTradeService;

    @Autowired
    private AliPayService aliPayService;

    @Autowired
    private RedisCache redisCache;

    /**
     * 查询列表
     */
    @GetMapping("/list")
    @ApiOperation(value = "查询订单列表")
    public TableDataInfo list(OrderTrade orderTrade) {
        startPage();
        List<OrderTrade> list = orderTradeService.selectMallProductList(orderTrade);
        return getDataTable(list);
    }

    /**
     * 新增
     */
    @PostMapping("/add")
    @ApiOperation(value = "新增订单")
    public AjaxResult add(@RequestBody OrderTrade orderTrade) {
        // 获取当前用户
        Long userId = SecurityUtils.getUserId();
        if (userId == null) {
            return AjaxResult.warn("用户未登录");
        }
        orderTrade.setUserId(userId);
        orderTrade.setCreateBy(getUsername());
        return toAjax(orderTradeService.insertMallProduct(orderTrade));
    }

    /**
     * 修改
     */
    @PostMapping("/upda")
    @ApiOperation(value = "修改订单")
    public AjaxResult upda(@RequestBody OrderTrade orderTrade) {
        // 获取当前用户
        Long userId = SecurityUtils.getUserId();
        if (userId == null) {
            return AjaxResult.warn("用户未登录");
        }
        orderTrade.setUserId(userId);
        orderTrade.setUpdateBy(getUsername());
        return toAjax(orderTradeService.updateMallProduct(orderTrade));
    }

    /**
     * 删除
     */
    @PostMapping
    @ApiOperation(value = "删除订单")
    public AjaxResult remove(@RequestBody IdsParam ids) {
        orderTradeService.deleteMallProductByIds(ids);
        return success();
    }


    /**
     * 查询交易状态
     */
    @GetMapping("/queryTradeStatus")
    @ApiOperation(value = "查询交易状态")
    public AjaxResult queryTradeStatus(@Valid @NotBlank(message = "订单号不能为空") String outTradeNo) throws Exception {
        return aliPayService.queryTradeStatus(outTradeNo);


    }

    @GetMapping("/getTradStatus")
    public Object getTradStatus(String outTradeNo) throws Exception {
        Factory.setOptions(config);
        AlipayTradeQueryResponse query = Factory.Payment.Common().query(outTradeNo);
        Map<String, Object> map = JSONUtils.jsonToMap(query.getHttpBody());

        // 返回交易结果, 是否交易成功需要根据该对象中的 trade_status 来确定
        // trade_status 的枚举值如下, 请见 https://opendocs.alipay.com/apis/api_1/alipay.trade.query
        // WAIT_BUYER_PAY（交易创建，等待买家付款）
        // TRADE_CLOSED（未付款交易超时关闭，或支付完成后全额退款）
        // TRADE_SUCCESS（交易支付成功）
        // TRADE_FINISHED（交易结束，不可退款）
        return map.get("alipay_trade_query_response");
    }


    /**
     * 撤销交易
     */
    @GetMapping("/cancelTrade")
    public AjaxResult cancelTrade(String outTradeNo) throws Exception {
        // 关闭交易
        AlipayTradeCancelResponse cancel = Factory.Payment.Common().cancel(outTradeNo);
        if (cancel.getCode().equals("10000")) {
            return AjaxResult.success("关闭成功");
        }
        return AjaxResult.error("关闭失败");
    }

    /**
     * 关闭交易
     */
//    @GetMapping("/closeTrade")
//    public AjaxResult closeTrade(String outTradeNo) throws Exception {
//        // 关闭交易
//        AlipayTradeCloseResponse close = Factory.Payment.Common().close(outTradeNo);
//        if (close.getCode().equals("10000")) {
//            return AjaxResult.success("关闭成功");
//        }
//        return AjaxResult.error("关闭失败");
//    }


}
